@@ -165,7 +165,7 @@ static enum Mode flow_mode = MODE_RANDOM;
 static int flow_id = 0;
 
 json_t *
-get_parameters()
+get_parameters(const uint8_t fetch_all)
 {
   json_t *params = json_object();
   plugin_parameters_add_string_list(params, BPP_MODE, MODE_NB, mode_list, flow_mode, MODE_NB-1, "Mode");
@@ -196,13 +196,13 @@ set_parameters(const Context_t *ctx, const json_t *in_parameters)
 
 
 json_t *
-parameters(const Context_t *ctx, const json_t *in_parameters)
+parameters(const Context_t *ctx, const json_t *in_parameters, const uint8_t fetch_all)
 {
   if (NULL != in_parameters) {
     set_parameters(ctx, in_parameters);
   }
 
-  return get_parameters();
+  return get_parameters(fetch_all);
 }
 
 
