@@ -24,7 +24,7 @@
 static double volume_scale = 1;
 
 json_t *
-get_parameters()
+get_parameters(const uint8_t fetch_all)
 {
   json_t *params = json_object();
 
@@ -42,13 +42,13 @@ set_parameters(const Context_t *ctx, const json_t *in_parameters)
 
 
 json_t *
-parameters(const Context_t *ctx, const json_t *in_parameters)
+parameters(const Context_t *ctx, const json_t *in_parameters, const uint8_t fetch_all)
 {
   if (NULL != in_parameters) {
     set_parameters(ctx, in_parameters);
   }
 
-  return get_parameters();
+  return get_parameters(fetch_all);
 }
 
 #endif /* __GUM_H */
