@@ -36,7 +36,7 @@ run(Context_t *ctx)
 
   Buffer8_init_mask_3x3(active_buffer(ctx));
 
-  pthread_mutex_lock(&ctx->input->mutex);
+  xpthread_mutex_lock(&ctx->input->mutex);
   a = Input_random_short_range(ctx->input, 0, MAXX);
   for (i = 0; i < (ctx->input->size - 1); i++) {
     b = Input_random_short_range(ctx->input, 0, MAXX);
@@ -45,5 +45,5 @@ run(Context_t *ctx)
     }
     a = b;
   }
-  pthread_mutex_unlock(&ctx->input->mutex);
+  xpthread_mutex_unlock(&ctx->input->mutex);
 }
