@@ -33,11 +33,11 @@ run(Context_t *ctx)
   Pixel_t col = PIXEL_MINVAL;
 
   memmove((void *)src->buffer, (const void *)(src->buffer + sizeof(Pixel_t)), BUFFSIZE - 1);
-  pthread_mutex_lock(&ctx->input->mutex);
+  xpthread_mutex_lock(&ctx->input->mutex);
   if (ctx->input->on_beat) {
     col = PIXEL_MAXVAL;
   }
-  pthread_mutex_unlock(&ctx->input->mutex);
+  xpthread_mutex_unlock(&ctx->input->mutex);
   v_line_nc(src, MAXX, MINY, MAXY, col);
   v_line_nc(src, MINX, MINY, MAXY, PIXEL_MINVAL);
 }
