@@ -42,11 +42,11 @@ run(Context_t *ctx)
 
   dst = start = passive_buffer(ctx)->buffer;
 
-  pthread_mutex_lock(&ctx->cam_mtx[ctx->cam]);
+  xpthread_mutex_lock(&ctx->cam_mtx[ctx->cam]);
   src1 = ctx->cam_save[ctx->cam][0]->buffer;
   src2 = ctx->cam_ref[ctx->cam]->buffer;
   for (; dst < start + BUFFSIZE * sizeof(Pixel_t); src1++, src2++, dst++) {
     *dst = abs(*src1 - *src2);
   }
-  pthread_mutex_unlock(&ctx->cam_mtx[ctx->cam]);
+  xpthread_mutex_unlock(&ctx->cam_mtx[ctx->cam]);
 }
