@@ -30,7 +30,7 @@ enum LayerMode mode = LM_OVERLAY;
 void
 run(Context_t *ctx)
 {
-  pthread_mutex_lock(&ctx->cam_mtx[ctx->cam]);
+  xpthread_mutex_lock(&ctx->cam_mtx[ctx->cam]);
   Buffer8_copy(ctx->cam_save[ctx->cam][0], passive_buffer(ctx));
-  pthread_mutex_unlock(&ctx->cam_mtx[ctx->cam]);
+  xpthread_mutex_unlock(&ctx->cam_mtx[ctx->cam]);
 }
