@@ -69,10 +69,10 @@ SDL_refresh_32bpp(Context_t *ctx)
   const int depth = 24, pitch = 3 * WIDTH;
   const Uint32 pixel_format = SDL_PIXELFORMAT_RGB24;
 
-  pthread_mutex_lock(&ctx->frame_mutex);
+  xpthread_mutex_lock(&ctx->frame_mutex);
   SDL_Surface *surf = SDL_CreateRGBSurfaceWithFormatFrom((void *)ctx->frame, WIDTH, HEIGHT,
                       depth, pitch, pixel_format);
-  pthread_mutex_unlock(&ctx->frame_mutex);
+  xpthread_mutex_unlock(&ctx->frame_mutex);
   assert(NULL != surf);
   if (SDL_BlitScaled(surf, NULL, SDL_GetWindowSurface(window), NULL) < 0) {
     xerror("SDL_BlitScaled failed\n");
@@ -250,7 +250,7 @@ create(Context_t *ctx)
     xerror("[2] SDL_UpdateWindowSurface failed: %s\n", SDL_GetError());
   }
 
-  pthread_create(&thread, NULL, osd_thread, (void *)ctx);
+  xpthread_create(&thread, NULL, osd_thread, (void *)ctx);
 
   return 1;
 }
@@ -259,7 +259,7 @@ create(Context_t *ctx)
 void
 destroy(Context_t *ctx)
 {
-  pthread_join(thread, NULL);
+  xpthread_join(thread, NULL);
   SDL_DestroyWindow(window);
   SDL_Quit();
 }
