@@ -26,16 +26,18 @@
 
 typedef struct Alarm_s {
   BTimer_t *timer;
-  int32_t min;
-  int32_t max;
-  u_short delay;
+  int32_t  min;
+  int32_t  max;
+  int16_t  delay;
 } Alarm_t;
 
 
-Alarm_t *Alarm_new(const u_short, const u_short);
+Alarm_t *Alarm_new(const int32_t, const int32_t);
 void     Alarm_delete(Alarm_t *);
 void     Alarm_init(Alarm_t *);
 int      Alarm_ring(Alarm_t *);
 float    Alarm_elapsed_pct(Alarm_t *); /* percentage of alarm time elapsed */
+void     Alarm_update(Alarm_t *, const int32_t, const int32_t);
+void     Alarm_trigger(Alarm_t *);
 
 #endif /* __BINIOU_ALARM_H */
