@@ -124,19 +124,19 @@ biniou_new(const char *datadir, const char *pluginsdir,
     /* Images */
     images_thread_args.buf = g_strdup_printf("%s/images/", datadir);
     images_thread_args.themes = themes;
-    pthread_create(&images_thread, NULL, biniou_images_thread, (void *)&images_thread_args);
+    xpthread_create(&images_thread, NULL, biniou_images_thread, (void *)&images_thread_args);
 
     /* Colormaps */
     colormaps_thread_args.buf = g_strdup_printf("%s/colormaps/", datadir);
-    pthread_create(&colormaps_thread, NULL, biniou_colormaps_thread, (void *)&colormaps_thread_args);
+    xpthread_create(&colormaps_thread, NULL, biniou_colormaps_thread, (void *)&colormaps_thread_args);
 
     /* Paths */
     paths_thread_args.buf = g_strdup_printf("%s/paths", datadir);
-    pthread_create(&paths_thread, NULL, biniou_paths_thread, (void *)&paths_thread_args);
+    xpthread_create(&paths_thread, NULL, biniou_paths_thread, (void *)&paths_thread_args);
 
-    pthread_join(images_thread, NULL);
-    pthread_join(colormaps_thread, NULL);
-    pthread_join(paths_thread, NULL);
+    xpthread_join(images_thread, NULL);
+    xpthread_join(colormaps_thread, NULL);
+    xpthread_join(paths_thread, NULL);
   } else {
     Colormaps_new(NULL);
   }
