@@ -232,6 +232,32 @@ Buffer8_overlay(Buffer8_t *s1, const Buffer8_t *s2)
 }
 
 
+void
+Buffer8_AND(Buffer8_t *dst, const Buffer8_t *src)
+{
+  /* AND pixels from dst with pixels from src */
+  Pixel_t *d = dst->buffer;
+  const Pixel_t *s = src->buffer;
+
+  for ( ; d < dst->buffer + BUFFSIZE*sizeof(Pixel_t); d++, s++) {
+    *d &= *s;
+  }
+}
+
+
+void
+Buffer8_OR(Buffer8_t *dst, const Buffer8_t *src)
+{
+  /* OR pixels from dst with pixels from src */
+  Pixel_t *d = dst->buffer;
+  const Pixel_t *s = src->buffer;
+
+  for ( ; d < dst->buffer + BUFFSIZE*sizeof(Pixel_t); d++, s++) {
+    *d |= *s;
+  }
+}
+
+
 void
 Buffer8_XOR(Buffer8_t *dst, const Buffer8_t *src)
 {
@@ -258,6 +284,30 @@ Buffer8_average(Buffer8_t *s1, const Buffer8_t *s2)
 }
 
 
+static uint8_t gray8[256];
+
+void
+init_gray8()
+{
+  // rescale Y values (16..235) to full 0..255
+  // not all values are used but we want to avoid substracting 16
+  // on each pixel :)
+  memset(&gray8, 0, 256 * sizeof(uint8_t));
+  for (uint8_t i = 16; i <= 235; ++i) {
+    gray8[i] = (uint8_t)((i - 16.0) / (235 - 16) * 255);
+  }
+}
+
+
+void
+Buffer8_YUV_to_full_gray(Buffer8_t *buff)
+{
+  for (uint32_t i = 0; i < BUFFSIZE; ++i) {
+    buff->buffer[i] = gray8[buff->buffer[i]];
+  }
+}
+
+
 void
 gray_scale(Pixel_t *grey_to, const uint16_t width, const uint16_t height, const Pixel_t *grey_data)
 {
