@@ -465,6 +465,8 @@ Buffer8_expand_border(Buffer8_t *buff)
 void Buffer8_randomize(Buffer8_t *);
 
 void Buffer8_overlay(Buffer8_t *, const Buffer8_t *);
+void Buffer8_AND(Buffer8_t *, const Buffer8_t *);
+void Buffer8_OR(Buffer8_t *, const Buffer8_t *);
 void Buffer8_XOR(Buffer8_t *, const Buffer8_t *);
 void Buffer8_average(Buffer8_t *, const Buffer8_t *);
 
@@ -504,6 +506,8 @@ Buffer8_flip_h(Buffer8_t *buff)
 
 
 void gray_scale(Pixel_t *, const uint16_t, const uint16_t, const Pixel_t *);
+void init_gray8();
+void Buffer8_YUV_to_full_gray(Buffer8_t *);
 void Buffer8_substract_y(const Buffer8_t *, const Buffer8_t *, const Pixel_t, const Buffer8_t *);
 
 #endif /* __BINIOU_BUFFER_8BITS_H */
