@@ -20,21 +20,21 @@
 #ifndef __BINIOU_CMAP_8BITS_H
 #define __BINIOU_CMAP_8BITS_H
 
+#include <jansson.h>
 #include "rgba.h"
 
 
 typedef struct Cmap8_s {
-  uint32_t   id;      /* our unique hash */
-  char   *name;       /* colormap name */
-  char   *filename;   /* where on the filesystem it was loaded from */
-  rgba_t colors[256]; /* the 256 RGBA palette */
-  int    min;         /* min intensity color index */
-  int    max;         /* max intensity color index */
-  u_char compressed;  /* colormap loaded from a binary file */
+  uint32_t id;          /* our unique hash */
+  char     *name;       /* colormap name */
+  char     *filename;   /* where on the filesystem it was loaded from */
+  rgba_t   colors[256]; /* the 256 RGBA palette */
+  uint8_t  min;         /* min intensity color index */
+  uint8_t  max;         /* max intensity color index */
+  uint8_t  compressed;  /* colormap loaded from a binary file */
 } Cmap8_t;
 
 
-/* TODO Cmap8_new(Cmap8 *, uint32_t, const char *, const char *) ? */
 Cmap8_t *Cmap8_new(void);
 void Cmap8_delete(Cmap8_t *);
 
@@ -45,5 +45,6 @@ void Cmap8_findMinMax(Cmap8_t *);
 int  Cmap8_save(Cmap8_t *);
 void Cmap8_shift_left(Cmap8_t *);
 
+json_t *Cmap8_to_json(const Cmap8_t *);
 
 #endif /* __BINIOU_CMAP_8BITS_H */
