@@ -22,7 +22,7 @@
 
 
 #ifdef WITH_WEBCAM
-extern int hflip, vflip, webcams;
+extern uint8_t hflip, vflip, desired_webcams;
 extern char *video_base;
 #endif
 extern uint8_t  statistics;
@@ -34,9 +34,7 @@ extern uint8_t  encoding;
 extern char    *playlist_filename;
 extern char    *audio_file;
 extern uint8_t  enable_osd;
-#ifdef WITH_ULFIUS
 extern uint8_t  usage_statistics;
-#endif
 
 
 #define MIN_WIDTH  80
@@ -74,10 +72,8 @@ usage()
 #endif
          "\t-E, --start-encoding\tStart encoding directly\n"
          "\t-F, --fade <delay>\tSet fade delay (in seconds)\n"
-#ifdef WITH_ULFIUS
          "\t-G, --enable-sdl2-gui\tEnable the legacy SDL2 GUI\n"
          "\t-N, --no-statistics\tDo not send usage statistics\n"
-#endif
          "\t-P, --playlist <file>\tSet playlist file\n"
          "\t-S, --stats\t\tDisplay statistics\n"
 #ifdef WITH_WEBCAM
@@ -90,10 +86,6 @@ usage()
          "\tInput plugins: " INPUT_PLUGINS "\n"
          "\tOutput plugins: " OUTPUT_PLUGINS "\n"
          "\n"
-#ifdef MANLINK
-         "Manual: file://" MANLINK "\n"
-         "\n"
-#endif
          , max_fps
          , pid_file
 #ifndef FIXED
@@ -101,7 +93,7 @@ usage()
          , DEFAULT_HEIGHT
 #endif
 #ifdef WITH_WEBCAM
-         , webcams
+         , desired_webcams
 #endif
         );
 
@@ -150,10 +142,8 @@ getargs(int argc, char **argv)
     {"device", required_argument, NULL, 'D'},
 #endif
     {"fade", required_argument, NULL, 'F'},
-#ifdef WITH_ULFIUS
     {"enable-sdl2-gui", no_argument, NULL, 'G'},
     {"no-statistics", no_argument, NULL, 'N'},
-#endif
     {"playlist", required_argument, NULL, 'P'},
     {"stats", no_argument, NULL, 'S'},
 #ifdef WITH_WEBCAM
@@ -340,11 +330,11 @@ getargs(int argc, char **argv)
         break;
 
       case 'W': /* webcams */
-        webcams = xatol(optarg);
-        if ((webcams >= 0) && (webcams <= MAX_CAMS)) {
-          VERBOSE(printf("[c] webcam: grabbing %d device%s\n", webcams, (webcams == 1 ? "": "s")));
+        desired_webcams = xatol(optarg);
+        if (desired_webcams <= MAX_CAMS) {
+          VERBOSE(printf("[c] webcam: grabbing %d device%s\n", desired_webcams, (desired_webcams == 1 ? "": "s")));
         } else {
-          webcams = 1;
+          desired_webcams = 1;
         }
         break;
 
@@ -377,7 +367,6 @@ getargs(int argc, char **argv)
         VERBOSE(printf("[c] Fading delay set to %f\n", fade_delay));
         break;
 
-#ifdef WITH_ULFIUS
       case 'G':
         enable_osd = 1;
         VERBOSE(printf("[c] Enabling legacy SDL2 GUI\n"));
@@ -387,7 +376,6 @@ getargs(int argc, char **argv)
         usage_statistics = 0;
         VERBOSE(printf("[c] Not sending statistics usage\n"));
         break;
-#endif
 
       default:
         usage();
