@@ -69,19 +69,10 @@ extern unsigned short WIDTH, HEIGHT;
 /* volume scaling */
 #define VOLUME_SCALE_STEP 0.1
 
-/* 3D scale factor */
-#define SCALE_FACTOR_MIN  1.03
-#define SCALE_FACTOR_MULT 0.9 // OSD changes via mouse wheel
-/* 3D rotations */
-#define DEFAULT_ROT_AMOUNT 0.0025
-#define ROT_AMOUNT_MIN     0.001
-/* rotations factor */
-#define DEFAULT_ROT_FACTOR 4
-
 /* delay for ancillary threads (OSD, webcams) */
-#define THREADS_DELAY 40
+#define THREADS_DELAY 100
 
 /* default fps */
-#define DEFAULT_MAX_FPS 50
+#define DEFAULT_MAX_FPS 25
 
 #endif /* __BINIOU_CONSTANTS_H */
