@@ -34,13 +34,7 @@ extern uint8_t encoding;
 extern int override_webcam;
 // playlist
 extern char *playlist_filename;
-// legacy SDL2 GUI
-#ifdef WITH_ULFIUS
-extern uint8_t enable_osd;
 extern uint8_t usage_statistics;
-#else
-uint8_t enable_osd = 1;
-#endif
 
 
 static enum ShufflerMode random_modes[MAX_TIMERS] = {
@@ -67,16 +61,15 @@ static pthread_t thr[MAX_CAMS];
 static void
 Context_open_webcam(Context_t *ctx)
 {
-  int i;
   uint8_t try = 0;
 
   parse_options();
 
-  for (i = 0; i < MAX_CAMS; i++) {
+  for (uint8_t i = 0; i < MAX_CAMS; i++) {
     pthread_mutex_init(&ctx->cam_mtx[i], NULL);
   }
 
-  for (i = 0; (i < ctx->webcams) && (try < MAX_TRIES); i++) {
+  for (uint8_t i = 0; (i < ctx->webcams) && (try < MAX_TRIES); i++) {
 retry:
       cams[i] = xmalloc(sizeof(webcam_t));
 
@@ -91,7 +84,7 @@ retry:
           list_inputs(cams[i]);
           start_capturing(cams[i]);
 
-          pthread_create(&thr[i], NULL, loop, (void *)cams[i]);
+          xpthread_create(&thr[i], NULL, loop, (void *)cams[i]);
         } else {
           VERBOSE(printf("[i] Webcam: failed to initialize device #%d\n", i));
           close_device(cams[i]);
@@ -109,7 +102,7 @@ retry:
 
 
 Context_t *
-Context_new(const int webcams)
+Context_new(const uint8_t desired_webcams)
 {
   Context_t *ctx = xcalloc(1, sizeof(Context_t));
 
@@ -122,10 +115,10 @@ Context_new(const int webcams)
     ctx->buffers[i] = Buffer8_new();
   }
 
-  ctx->webcams = webcams;
+  ctx->webcams = desired_webcams;
 #ifdef WITH_WEBCAM
   {
-    for (uint8_t k = 0; k < webcams; k++) {
+    for (uint8_t k = 0; k < ctx->webcams; k++) {
       for (uint8_t i = 0; i < CAM_SAVE; i++) {
         ctx->cam_save[k][i] = Buffer8_new();
       }
@@ -169,17 +162,17 @@ Context_new(const int webcams)
   }
 
 #ifdef WITH_WEBCAM
-  VERBOSE(printf("[i] Initializing %d webcams base: %s\n", webcams, video_base));
+  VERBOSE(printf("[i] Initializing %d webcams base: %s\n", desired_webcams, video_base));
 
   Context_open_webcam(ctx);
 
-  for (uint8_t i = 0; i < webcams; i++) {
+  for (uint8_t i = 0; i < desired_webcams; i++) {
     Buffer8_copy(ctx->target_pic->buff, ctx->cam_save[i][0]);
   }
 
-  if (webcams > 1) {
-    VERBOSE(printf("[+] Creating webcams shuffler (%d webcams)\n", webcams));
-    ctx->webcams_shuffler = Shuffler_new(webcams);
+  if (ctx->webcams > 1) {
+    VERBOSE(printf("[+] Creating webcams shuffler (%d webcams)\n", ctx->webcams));
+    ctx->webcams_shuffler = Shuffler_new(ctx->webcams);
     Shuffler_set_mode(ctx->webcams_shuffler, Context_get_shuffler_mode(BD_WEBCAMS));
 #ifdef DEBUG
     Shuffler_verbose(ctx->webcams_shuffler);
@@ -201,20 +194,24 @@ Context_new(const int webcams)
 
   ctx->allow_random_changes = 1;
 
+  // Gray scale
+  init_gray8();
+
   return ctx;
 }
 
 
 #ifdef WITH_WEBCAM
 static void
-Context_close_webcam(const uint8_t cam_no)
+Context_close_webcam(Context_t *ctx, const uint8_t cam_no)
 {
   if (NULL != cams[cam_no]) {
-    pthread_join(thr[cam_no], NULL);
+    xpthread_join(thr[cam_no], NULL);
     stop_capturing(cams[cam_no]);
     uninit_device(cams[cam_no]);
     close_device(cams[cam_no]);
     xfree(cams[cam_no]);
+    xpthread_mutex_destroy(&ctx->cam_mtx[cam_no]);
   }
 }
 #endif
@@ -223,29 +220,21 @@ Context_close_webcam(const uint8_t cam_no)
 void
 Context_delete(Context_t *ctx)
 {
-  int i;
   GSList *outputs = ctx->outputs, *_outputs = outputs;
 
-#ifdef WITH_ULFIUS
   if (usage_statistics) {
     Context_statistics(ctx);
   }
-#endif
 
 #ifdef WITH_WEBCAM
   VERBOSE(printf("[i] Closing %d webcams\n", ctx->webcams));
-  if (ctx->webcams) {
-    int i;
-
-    for (i = 0; i < ctx->webcams; i++) {
-      Context_close_webcam(i);
+  if (desired_webcams)
+    for (uint8_t i = 0; i < desired_webcams; i++) {
+      Context_close_webcam(ctx, i);
     }
-  }
   xfree(video_base);
-  if (ctx->webcams > 1) {
-    Shuffler_delete(ctx->webcams_shuffler);
-    Alarm_delete(ctx->a_webcams);
-  }
+  Shuffler_delete(ctx->webcams_shuffler);
+  Alarm_delete(ctx->a_webcams);
 #endif
 
   VERBOSE(printf("[i] %"PRIu64" frames\n", frames));
@@ -262,15 +251,14 @@ Context_delete(Context_t *ctx)
   g_slist_free(_outputs);
 
   VERBOSE(printf("[+] Freeing buffers... "));
-  for (i = 0; i < NSCREENS; i++) {
+  for (uint8_t i = 0; i < NSCREENS; i++) {
     VERBOSE(printf("%d ", i));
     Buffer8_delete(ctx->buffers[i]);
   }
 #ifdef WITH_WEBCAM
   {
-    int k;
-    for (k = 0; k < ctx->webcams; k++) {
-      for (i = 0; i < CAM_SAVE; i++) {
+    for (uint8_t k = 0; k < desired_webcams; k++) {
+      for (uint8_t i = 0; i < CAM_SAVE; i++) {
         Buffer8_delete(ctx->cam_save[k][i]);
       }
       Buffer8_delete(ctx->cam_ref[k]);
@@ -314,11 +302,12 @@ Context_delete(Context_t *ctx)
   b_timer_delete(ctx->track_timer);
   Shuffler_delete(ctx->playlist_shuffler);
 
-  for (i = 0; i < CAM_SAVE; i++) {
+  for (uint8_t i = 0; i < CAM_SAVE; i++) {
     Buffer8_delete(ctx->video_save[i]);
   }
 
   xfree(ctx->frame);
+  xpthread_mutex_destroy(&ctx->frame_mutex);
   xfree(ctx);
 }
 
