@@ -33,9 +33,7 @@
 #include "alarm.h"
 #include "brandom.h"
 #include "buffer_RGBA.h"
-#ifdef WITH_ULFIUS
 #include "bulfius.h"
-#endif
 
 #define NFPS          25 // to get mean fps
 #define MAX_BANKS     24
@@ -176,11 +174,9 @@ typedef struct Context_s {
   Buffer8_t *random;
 
   // Ulfius
-#ifdef WITH_ULFIUS
   struct _u_instance instance;
   GSList *ws_clients;
   pthread_mutex_t ws_clients_mutex;
-#endif
 
   // Replay feature
   GQueue *replay;
@@ -204,7 +200,7 @@ typedef struct Context_s {
 } Context_t;
 
 
-Context_t *Context_new(const int);
+Context_t *Context_new(const uint8_t);
 void Context_delete(Context_t *);
 
 void Context_set(Context_t *);
@@ -312,7 +308,6 @@ double Context_get_volume_scale(const Context_t *);
 void Context_mix_buffers(const Context_t *, Buffer8_t *[2]);
 void Context_interleave_buffers(const Context_t *);
 
-#ifdef WITH_ULFIUS
 void Context_start_ulfius(Context_t *);
 void Context_stop_ulfius(Context_t *);
 
@@ -322,7 +317,6 @@ void Context_websocket_send_command_result(Context_t *, const enum Command, json
     const struct _websocket_manager *);
 // Usage statistics
 void Context_statistics(const Context_t *);
-#endif
 
 // Replay
 void Context_init_replay(Context_t *);
