@@ -124,7 +124,7 @@ Context_command(Context_t *ctx, const enum Command cmd)
         ctx->locked = NULL;
       }
       if (NULL != plugins->selected->parameters) {
-        json_object_set_new(res, "parameters", plugins->selected->parameters(ctx, NULL));
+        json_object_set_new(res, "parameters", plugins->selected->parameters(ctx, NULL, 0));
       } else {
         json_object_set_new(res, "parameters", json_null());
       }
@@ -294,9 +294,9 @@ Context_command(Context_t *ctx, const enum Command cmd)
       printf(">>> CMD_APP_SET_WEBCAM_REFERENCE\n");
 #endif
       if (ctx->webcams) {
-        pthread_mutex_lock(&ctx->cam_mtx[ctx->cam]);
+        xpthread_mutex_lock(&ctx->cam_mtx[ctx->cam]);
         Buffer8_copy(ctx->cam_save[ctx->cam][0], ctx->cam_ref[ctx->cam]);
-        pthread_mutex_unlock(&ctx->cam_mtx[ctx->cam]);
+        xpthread_mutex_unlock(&ctx->cam_mtx[ctx->cam]);
       } else {
         printf("[i] No webcams in use\n");
       }
@@ -413,7 +413,7 @@ Context_command(Context_t *ctx, const enum Command cmd)
       res = json_object();
       json_object_set_new(res, "selected_plugin", json_string(plugins->selected->name));
       if (NULL != plugins->selected->parameters) {
-        json_object_set_new(res, "parameters", plugins->selected->parameters(ctx, NULL));
+        json_object_set_new(res, "parameters", plugins->selected->parameters(ctx, NULL, 0));
         json_object_set_new(res, "selected_param", json_integer(plugins->selected->selected_param));
       }
       json_object_set_new(res, "sequence", Sequence_to_json(ctx->sm->cur, 1, 0));
@@ -606,9 +606,7 @@ Context_process_command(Context_t *ctx, const enum Command cmd, const void *from
     json_object_set_new(res, "error", json_string("No such command"));
   }
 
-#ifdef WITH_ULFIUS
   Context_websocket_send_command_result(ctx, cmd, res, (struct _websocket_manager *)from);
-#endif
 
   return res;
 }
