@@ -46,7 +46,7 @@ Context_make_GL_gray_texture(Context_t *ctx, const uint8_t cam)
   const Pixel_t *data = NULL;
 
   texture = ctx->cam_textures[cam];
-  pthread_mutex_lock(&ctx->cam_mtx[cam]);
+  xpthread_mutex_lock(&ctx->cam_mtx[cam]);
   data = ctx->cam_save[cam][0]->buffer;
 
   glEnable(GL_TEXTURE_2D);
@@ -55,6 +55,6 @@ Context_make_GL_gray_texture(Context_t *ctx, const uint8_t cam)
   glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR);
   glTexImage2D(GL_TEXTURE_2D, 0, GL_LUMINANCE, WIDTH, HEIGHT, 0,
                GL_LUMINANCE, GL_UNSIGNED_BYTE, data);
-  pthread_mutex_unlock(&ctx->cam_mtx[cam]);
+  xpthread_mutex_unlock(&ctx->cam_mtx[cam]);
 }
 #endif
