@@ -120,6 +120,14 @@ Context_sequence(Context_t *ctx)
         Buffer8_overlay(active_buffer(ctx), passive_buffer(ctx));
         break;
 
+      case LM_AND:
+        Buffer8_AND(active_buffer(ctx), passive_buffer(ctx));
+        break;
+
+      case LM_OR:
+        Buffer8_OR(active_buffer(ctx), passive_buffer(ctx));
+        break;
+
       case LM_XOR:
         Buffer8_XOR(active_buffer(ctx), passive_buffer(ctx));
         break;
@@ -224,9 +232,7 @@ Context_run(Context_t *ctx)
   } else {
     if (ctx->allow_random_changes) {
       if (Context_auto_change(ctx)) {
-#ifdef WITH_ULFIUS
         Context_websocket_send_state(ctx);
-#endif
       }
     }
   }
@@ -235,9 +241,7 @@ Context_run(Context_t *ctx)
   // Timer elapsed ?
   if (ctx->cf->on && Alarm_ring(ctx->a_cmaps)) {
     CmapFader_random(ctx->cf);
-#ifdef WITH_ULFIUS
     Context_websocket_send_state(ctx);
-#endif
   }
   // Fade colormap
   if (CmapFader_ring(ctx->cf)) {
@@ -250,9 +254,7 @@ Context_run(Context_t *ctx)
     // Timer elapsed ?
     if (ctx->imgf->on && Alarm_ring(ctx->a_images)) {
       ImageFader_random(ctx->imgf);
-#ifdef WITH_ULFIUS
       Context_websocket_send_state(ctx);
-#endif
     }
     // Fade image
     if (ImageFader_ring(ctx->imgf)) {
@@ -334,10 +336,10 @@ Context_run(Context_t *ctx)
   }
 
   // store current RGBA frame
-  pthread_mutex_lock(&ctx->frame_mutex);
+  xpthread_mutex_lock(&ctx->frame_mutex);
   xfree(ctx->frame);
   ctx->frame = export_RGB_active_buffer(ctx, 1);
-  pthread_mutex_unlock(&ctx->frame_mutex);
+  xpthread_mutex_unlock(&ctx->frame_mutex);
 
   for ( ; NULL != outputs; outputs = g_slist_next(outputs)) {
     Plugin_t *output = (Plugin_t *)outputs->data;
