@@ -52,7 +52,7 @@ Context_process_ui_command(Context_t *ctx, const enum Command cmd, const json_t
           res = json_object();
           json_object_set_new(res, "selected_plugin_dname", json_string(p->dname));
           if (NULL != p->parameters) {
-            json_object_set_new(res, "parameters", p->parameters(ctx, NULL));
+            json_object_set_new(res, "parameters", p->parameters(ctx, NULL, 0));
           }
         }
       }
@@ -81,7 +81,7 @@ Context_process_ui_command(Context_t *ctx, const enum Command cmd, const json_t
           Shuffler_reinit(sequences->shuffler);
         }
 #ifdef WITH_WEBCAM
-        else if ((webcams > 1) && is_equal(what, "webcams")) {
+        else if ((ctx->webcams > 1) && is_equal(what, "webcams")) {
           Shuffler_set_mode(ctx->webcams_shuffler, Shuffler_parse_mode(mode));
           Shuffler_reinit(ctx->webcams_shuffler);
         }
