@@ -33,12 +33,12 @@ uint8_t libbiniou_verbose = 1;
 
 char *data_dir = NULL;
 #ifdef WITH_WEBCAM
-int webcams = 1;
-int hflip = 1;
-int vflip = 1;
+uint8_t desired_webcams = 1;
+uint8_t hflip = 1;
+uint8_t vflip = 1;
 char *video_base;
 #else
-int webcams = 0;
+uint8_t desired_webcams = 0;
 #endif
 
 uint8_t max_fps = DEFAULT_MAX_FPS;
@@ -52,7 +52,5 @@ char *audio_file = NULL;
 uint8_t  encoding = 0;
 
 int override_webcam = 0;
-uint8_t enable_osd = 0;
-#ifdef WITH_ULFIUS
 uint8_t usage_statistics = 1;
-#endif
+uint8_t enable_osd = 0;
