@@ -41,6 +41,6 @@ extern Context_t   *context;
 #else
 #define MAX_TIMERS 3
 #endif
-extern int webcams;
+extern uint8_t desired_webcams;
 
 #endif /* __BINIOU_GLOBALS_H */
