@@ -69,7 +69,6 @@ Image8_load_any(Image8_t *img, const char *file)
   MagickBooleanType status;
   int res = -1;
 
-  MagickWandGenesis();
   wand = NewMagickWand();
   if (NULL != wand) {
     status = MagickReadImage(wand, file);
@@ -87,33 +86,32 @@ Image8_load_any(Image8_t *img, const char *file)
     }
     DestroyMagickWand(wand);
   }
-  MagickWandTerminus();
 
   return res;
 }
 
 
 int
-Image8_load(Image8_t *pic, const uint32_t id, const char *dir, const char *filename)
+Image8_load(Image8_t *img, const uint32_t id, const char *dir, const char *filename)
 {
   char *file = g_strdup_printf("%s/%s", dir, filename);
 
-  if (Image8_load_any(pic, file) != 0) {
+  if (Image8_load_any(img, file) != 0) {
     g_free(file);
     return -1;
   }
   g_free(file);
 
-  xfree(pic->name);
-  pic->name = strdup(filename);
-  xfree(pic->dname);
-  pic->dname = strdup(pic->name);
+  xfree(img->name);
+  img->name = strdup(filename);
+  xfree(img->dname);
+  img->dname = strdup(img->name);
 
-  if (NULL != (file = strchr(pic->dname, '.'))) {
+  if (NULL != (file = strchr(img->dname, '.'))) {
     *file = '\0';  /* spr0tch */
   }
 
-  pic->id = id;
+  img->id = id;
 
   return 0;
 }
@@ -135,3 +133,35 @@ Image8_copy(const Image8_t *from, Image8_t *to)
 
   Buffer8_copy(from->buff, to->buff);
 }
+
+
+void
+Image8_to_PNG(const Image8_t *img, uint8_t **data, uint32_t *datalen)
+{
+  MagickWand *wand = NULL;
+
+  *data = NULL;
+  *datalen = 0;
+  wand = NewMagickWand();
+  if (NULL != wand) {
+    MagickBooleanType status;
+
+    status = MagickConstituteImage(wand, WIDTH, HEIGHT, "I", CharPixel, img->buff->buffer);
+    if (status == MagickTrue) {
+      status = MagickFlipImage(wand);
+      if (status == MagickTrue) {
+        status = MagickSetImageFormat(wand, "PNG");
+        if (status == MagickTrue) {
+          size_t png_datalen;
+          uint8_t *png_data = MagickGetImageBlob(wand, &png_datalen);
+
+          *datalen = png_datalen;
+          *data = xmalloc(png_datalen * sizeof(uint8_t));
+          memcpy(*data, png_data, png_datalen * sizeof(uint8_t));
+          MagickRelinquishMemory(png_data);
+        }
+      }
+    }
+    DestroyMagickWand(wand);
+  }
+}
