@@ -117,71 +117,87 @@ ImageFader_run(ImageFader_t *pf)
 void
 ImageFader_set(ImageFader_t *pf)
 {
-  Fader_t *fader = pf->fader;
+  if (NULL != pf) {
+    Fader_t *fader = pf->fader;
 
-  pf->dst = images->imgs[fader->target];
+    pf->dst = images->imgs[fader->target];
 
-  if (NULL != pf->dst->name) {
+    if (NULL != pf->dst->name) {
 #ifdef DEBUG_IMAGEFADER
-    VERBOSE(printf("[i] Using image '%s'\n", pf->dst->name));
+      VERBOSE(printf("[i] Using image '%s'\n", pf->dst->name));
 #endif
-  } else {
-    xerror("Image without name, WTF #@!\n");
-  }
+    } else {
+      xerror("Image without name, WTF #@!\n");
+    }
 
-  ImageFader_init(pf);
-  fader->fading = 1;
+    ImageFader_init(pf);
+    fader->fading = 1;
+  }
 }
 
 
 void
 ImageFader_prev(ImageFader_t *pf)
 {
-  DEC(pf->fader->target, images->size);
-  ImageFader_set(pf);
+  if (NULL != pf) {
+    DEC(pf->fader->target, images->size);
+    ImageFader_set(pf);
+  }
 }
 
 
 void
 ImageFader_prev_n(ImageFader_t *pf, const uint16_t n)
 {
-  for (uint16_t i = 0; i < n; i++) {
-    DEC(pf->fader->target, images->size);
+  if (NULL != pf) {
+    for (uint16_t i = 0; i < n; i++) {
+      DEC(pf->fader->target, images->size);
+    }
+    ImageFader_set(pf);
   }
-  ImageFader_set(pf);
 }
 
 
 void
 ImageFader_next(ImageFader_t *pf)
 {
-  INC(pf->fader->target, images->size);
-  ImageFader_set(pf);
+  if (NULL != pf) {
+    INC(pf->fader->target, images->size);
+    ImageFader_set(pf);
+  }
 }
 
 
 void
 ImageFader_next_n(ImageFader_t *pf, const uint16_t n)
 {
-  for (uint16_t i = 0; i < n; i++) {
-    INC(pf->fader->target, images->size);
+  if (NULL != pf) {
+    for (uint16_t i = 0; i < n; i++) {
+      INC(pf->fader->target, images->size);
+    }
+    ImageFader_set(pf);
   }
-  ImageFader_set(pf);
 }
 
 
 void
 ImageFader_random(ImageFader_t *pf)
 {
-  pf->fader->target = Shuffler_get(pf->shf);
-  ImageFader_set(pf);
+  if (NULL != pf) {
+    pf->fader->target = Shuffler_get(pf->shf);
+    ImageFader_set(pf);
+  }
 }
 
 
 int
 ImageFader_ring(const ImageFader_t *pf)
 {
-  const Fader_t *fader = pf->fader;
+  if (NULL != pf) {
+    const Fader_t *fader = pf->fader;
 
-  return (fader->fading && ((b_timer_elapsed(fader->timer) * MFACTOR) > 0));
+    return (fader->fading && ((b_timer_elapsed(fader->timer) * MFACTOR) > 0));
+  } else {
+    return 0;
+  }
 }
