@@ -55,38 +55,29 @@ Layer_copy(const Layer_t *from)
 
 enum LayerMode
 LayerMode_from_string(const char *mode) {
-  if (is_equal(mode, "none"))
-  {
+  if (is_equal(mode, "none")) {
     return LM_NONE;
-  }
-  if (is_equal(mode, "normal"))
-  {
+  } else if (is_equal(mode, "normal")) {
+    return LM_NORMAL;
+  } else if (is_equal(mode, "overlay")) {
+    return LM_OVERLAY;
+  } else if (is_equal(mode, "and")) {
+    return LM_AND;
+  } else if (is_equal(mode, "or")) {
+    return LM_OR;
+  } else if (is_equal(mode, "xor")) {
+    return LM_XOR;
+  } else if (is_equal(mode, "average")) {
+    return LM_AVERAGE;
+  } else if (is_equal(mode, "interleave")) {
+    return LM_INTERLEAVE;
+  } else if (is_equal(mode, "random")) {
+    return LM_RANDOM;
+  } else {
+    printf("[!] Failed to parse mode '%s', setting to NORMAL\n", mode);
+
     return LM_NORMAL;
   }
-  if (is_equal(mode, "overlay"))
-  {
-    return LM_OVERLAY;
-  }
-  if (is_equal(mode, "xor"))
-  {
-    return LM_XOR;
-  }
-  if (is_equal(mode, "average"))
-  {
-    return LM_AVERAGE;
-  }
-  if (is_equal(mode, "interleave"))
-  {
-    return LM_INTERLEAVE;
-  }
-  if (is_equal(mode, "random"))
-  {
-    return LM_RANDOM;
-  }
-
-  printf("[!] Failed to parse mode '%s', setting to NORMAL\n", mode);
-
-  return LM_NORMAL;
 }
 
 
@@ -106,6 +97,14 @@ LayerMode_to_string(const enum LayerMode mode)
       return "overlay";
       break;
 
+    case LM_AND:
+      return "and";
+      break;
+
+    case LM_OR:
+      return "or";
+      break;
+
     case LM_XOR:
       return "xor";
       break;
@@ -139,6 +138,6 @@ LayerMode_to_OSD_string(const enum LayerMode mode)
 
     return NULL;
   } else {
-    return &"---\0NOR\0OVL\0XOR\0AVG\0ILV\0RND\0"[4 * mode * sizeof(char)];
+    return &"---\0NOR\0OVL\0AND\0OR \0XOR\0AVG\0ILV\0RND\0"[4 * mode * sizeof(char)];
   }
 }
