@@ -156,7 +156,7 @@ main(int argc, char **argv)
   b_rand_init();
 
   /* Create context */
-  context = Context_new(webcams);
+  context = Context_new(desired_webcams);
   Context_set_input_size(context, input_size);
 
   biniou_set_max_fps(max_fps);
@@ -179,7 +179,7 @@ main(int argc, char **argv)
 #ifdef DEBUG
              |B_INIT_VERBOSE
 #endif
-             , input_size, webcams);
+             , input_size, desired_webcams);
   xfree(themes);
 
   if (statistics) {
@@ -212,18 +212,16 @@ main(int argc, char **argv)
 
   biniou_set_random_mode(random_mode);
 
-#ifdef WITH_ULFIUS
   if (http_port) {
     Context_start_ulfius(context);
   }
-#endif
 
   /* Main loop */
   biniou_run();
 
-#ifdef WITH_ULFIUS
-  Context_stop_ulfius(context);
-#endif
+  if (http_port) {
+    Context_stop_ulfius(context);
+  }
 
   /* All done */
   biniou_delete();
