@@ -34,8 +34,8 @@ extern char window_decorations;
 extern int32_t x_origin;
 extern int32_t y_origin;
 #ifndef FIXED
-extern u_short width;
-extern u_short height;
+extern uint16_t width;
+extern uint16_t height;
 #endif
 extern enum RandomMode random_mode;
 extern char *pid_file;
@@ -45,5 +45,6 @@ void register_signals(void);
 void getargs(int, char **);
 void read_keyfile();
 void set_configuration(gchar *);
+void remove_pid_file();
 
 #endif /* __MAIN_H */
