@@ -107,7 +107,7 @@ Porteuse_draw(const Porteuse_t *p, Context_t *ctx, const int connect)
 
   assert(p->size <= ctx->input->size);
 
-  pthread_mutex_lock(&ctx->input->mutex);
+  xpthread_mutex_lock(&ctx->input->mutex);
 
   origin = p2d_add(&origin, &t->v_before);
   vy = ctx->input->data[p->channel][i];
@@ -173,5 +173,5 @@ Porteuse_draw(const Porteuse_t *p, Context_t *ctx, const int connect)
     origin = p2d_add(&origin, &t->v_after);
   }
 
-  pthread_mutex_unlock(&ctx->input->mutex);
+  xpthread_mutex_unlock(&ctx->input->mutex);
 }
