@@ -28,7 +28,7 @@ typedef struct Transform_s {
   Point2d_t v_before;
   Point2d_t v_i;
   Point2d_t v_after;
-  u_short   v_j_factor;
+  uint16_t   v_j_factor;
   float     cos_alpha;
   float     sin_alpha;
 } Transform_t;
@@ -39,12 +39,12 @@ typedef struct Porteuse_s {
   uint32_t    size;
   Point2d_t   origin;
   Transform_t *trans;
-  u_char      channel;
+  uint8_t      channel;
   Pixel_t     *color;
   uint8_t     *connect;
 } Porteuse_t;
 
-Porteuse_t *Porteuse_new(uint32_t, u_char);
+Porteuse_t *Porteuse_new(uint32_t, uint8_t);
 void Porteuse_delete(Porteuse_t *);
 
 void Porteuse_init_alpha(Porteuse_t *);
