@@ -20,11 +20,19 @@
 #include "params3d.h"
 #include "brandom.h"
 
+/* 3D scale factor */
+#define SCALE_FACTOR_MIN  1.03
+#define SCALE_FACTOR_MULT 0.9 // OSD changes via mouse wheel
+
+/* 3D rotations */
+#define DEFAULT_ROT_AMOUNT 0.001
+#define DEFAULT_ROT_FACTOR 50
+
 #define MAX_3D    10.0
-#define NSAMPLES  36 /* for the sphere */
+#define NSAMPLES  15 /* for the sphere */
 #define NSAMPLES2 ((float)(NSAMPLES))
 #define TSTEP     (2.0 * M_PI / NSAMPLES2)
-#define PSTEP     (M_PI / (NSAMPLES2-1))
+#define PSTEP     (M_PI / (NSAMPLES2 - 1))
 
 
 /* These are the Quadrants also ;) */
@@ -52,12 +60,11 @@ Point3d_t Sphere3d[NSAMPLES][NSAMPLES];
 static void
 init_sphere_3d(void)
 {
-  float theta, phi;
-  u_short it = 0, ip = 0;
+  uint8_t it = 0, ip = 0;
 
-  for (theta = 0; it < NSAMPLES; theta += TSTEP, it++) {
+  for (float theta = 0; it < NSAMPLES; theta += TSTEP, it++) {
     ip = 0;
-    for (phi = 0; ip < NSAMPLES; phi += PSTEP, ip++) {
+    for (float phi = 0; ip < NSAMPLES; phi += PSTEP, ip++) {
       Point3d_t *p = &Sphere3d[it][ip];
 
       p->pos.x = RHO * cosf(theta) * sinf(phi);
@@ -68,23 +75,34 @@ init_sphere_3d(void)
 }
 
 
-void
-Params3d_init(Params3d_t *p, const float rotate_amount, const double scale_factor,
-              const uint8_t rotation_factor)
+static void
+Params3d_set_scale_factor(Params3d_t *p)
 {
-  int i;
+  p->scale_factor = p->scale_factor0 * pow(SCALE_FACTOR_MULT, p->scale_factor_coeff);
+#ifdef DEBUG
+  VERBOSE(printf("[i] 3D scale factor coeff: %d => %.2f\n", p->scale_factor_coeff, p->scale_factor));
+#endif
+}
 
-  p->rotation_factor = rotation_factor;
 
-  p->rotate_amount = rotate_amount;
-  for (i = X_AXIS; i <= Z_AXIS; i++) {
-    p->rotations[i] = 0;
-    p->rotate_factor[i] = 0; // TODO get from configuration
-  }
-  update(p);
+void
+Params3d_set_defaults(Params3d_t *p)
+{
+  zero_3d(p);
+  p->scale_factor0 = HEIGHT / 3.0;
+  p->scale_factor_coeff = 1;
+  Params3d_set_scale_factor(p);
+  p->boundary = BOUNDARY_NONE;
+}
 
-  p->scale_factor = scale_factor;
-  p->draw_boundary = 0;
+
+void
+Params3d_init(Params3d_t *p)
+{
+  Params3d_set_defaults(p);
+
+  p->rotation_factor = DEFAULT_ROT_FACTOR;
+  p->rotate_amount = DEFAULT_ROT_AMOUNT;
 
   p->xs = p->xe = HWIDTH;
   p->ys = p->ye = HHEIGHT;
@@ -94,7 +112,6 @@ Params3d_init(Params3d_t *p, const float rotate_amount, const double scale_facto
 #endif
 
   init_sphere_3d();
-  zero_3d(p);
 
 #ifdef WITH_GL
   p->gl_fov = 45; /* FIXME empirical value */
@@ -102,22 +119,21 @@ Params3d_init(Params3d_t *p, const float rotate_amount, const double scale_facto
 }
 
 
+uint8_t
+Params3d_is_rotating(const Params3d_t *p)
+{
+  return (p->rotate_factor[X_AXIS]
+          || p->rotate_factor[Y_AXIS]
+          || p->rotate_factor[Z_AXIS]);
+}
+
 void
 Params3d_randomize(Params3d_t *p)
 {
   do {
-    int i;
-    // FIXME b_rand_int_range returns uint32_t !!!
-    // this should be b_rand_int_range(-RAND_FACTOR, RAND_FACTOR)..
-    p->rotate_factor[X_AXIS] = b_rand_int_range(0, p->rotation_factor);
-    p->rotate_factor[Y_AXIS] = b_rand_int_range(0, p->rotation_factor);
-    p->rotate_factor[Z_AXIS] = b_rand_int_range(0, p->rotation_factor);
-    // XXX poor random sign changing
-    for (i = X_AXIS; i <= Z_AXIS; i++) {
-      if (b_rand_boolean()) {
-        p->rotate_factor[i] = -p->rotate_factor[i];
-      }
-    }
+    p->rotate_factor[X_AXIS] = b_rand_int32_range(-p->rotation_factor, p->rotation_factor);
+    p->rotate_factor[Y_AXIS] = b_rand_int32_range(-p->rotation_factor, p->rotation_factor);
+    p->rotate_factor[Z_AXIS] = b_rand_int32_range(-p->rotation_factor, p->rotation_factor);
   } while (!Params3d_is_rotating(p));
 }
 
@@ -125,10 +141,8 @@ Params3d_randomize(Params3d_t *p)
 inline void
 draw_sphere_3d(const Params3d_t *params3d, Buffer8_t *b, const Pixel_t color)
 {
-  u_short it, ip;
-
-  for (it = 0; it < NSAMPLES; it++)
-    for (ip = 0; ip < NSAMPLES; ip++) {
+  for (uint8_t it = 0; it < NSAMPLES; it++)
+    for (uint8_t ip = 0; ip < NSAMPLES; ip++) {
       set_pixel_3d(params3d, b, &Sphere3d[it][ip], color);
     }
 }
@@ -137,18 +151,16 @@ draw_sphere_3d(const Params3d_t *params3d, Buffer8_t *b, const Pixel_t color)
 inline void
 draw_sphere_wireframe_3d(const Params3d_t *params3d, Buffer8_t *b, const Pixel_t color)
 {
-  u_short it, ip;
-
-  for (it = 0; it < NSAMPLES-1; it++) {
-    for (ip = 0; ip < NSAMPLES; ip++) {
+  for (uint8_t it = 0; it < NSAMPLES - 1; it++) {
+    for (uint8_t ip = 0; ip < NSAMPLES; ip++) {
       draw_line_3d(params3d, b, &Sphere3d[it][ip], &Sphere3d[it+1][ip], color);
     }
   }
-  for (ip = 0; ip < NSAMPLES; ip++) {
+  for (uint8_t ip = 0; ip < NSAMPLES; ip++) {
     draw_line_3d(params3d, b, &Sphere3d[0][ip], &Sphere3d[NSAMPLES-1][ip], color);
   }
-  for (it = 0; it < NSAMPLES; it++) {
-    for (ip = 0; ip < NSAMPLES-1; ip++) {
+  for (uint8_t it = 0; it < NSAMPLES; it++) {
+    for (uint8_t ip = 0; ip < NSAMPLES-1; ip++) {
       draw_line_3d(params3d, b, &Sphere3d[it][ip], &Sphere3d[it][ip+1], color);
     }
   }
@@ -197,8 +209,6 @@ Params3d_rotate(Params3d_t *p)
   float dx = (p->xe-p->xs)/(float)(WIDTH/8);
   float dy = (p->ye-p->ys)/(float)(HEIGHT/8);
 
-  /* printf ("dx= %f, dy= %f\n", dx, dy); */
-
   // BUGGY (Y/X) then check (X/Z)?!
   p->rotations[Y_AXIS] += dx;
   p->rotations[X_AXIS] += dy;
@@ -255,9 +265,7 @@ Params3d_rotate_GL(Params3d_t *p)
 inline void
 Params3d_change_rotations(Params3d_t *p)
 {
-  int i;
-
-  for (i = X_AXIS; i <= Z_AXIS; i++) {
+  for (uint8_t i = X_AXIS; i <= Z_AXIS; i++) {
     p->rotations[i] += (p->rotate_factor[i] * p->rotate_amount);
   }
   update(p);
@@ -286,3 +294,115 @@ update_z(Params3d_t *p)
   p->Cos[Z_AXIS] = cosf(p->rotations[Z_AXIS]);
   p->Sin[Z_AXIS] = sinf(p->rotations[Z_AXIS]);
 }
+
+
+static Boundaries_t
+Params3d_str2boundary(const char *str)
+{
+  if (is_equal(str, "none")) {
+    return BOUNDARY_NONE;
+  } else if (is_equal(str, "cube")) {
+    return BOUNDARY_CUBE;
+  } else if (is_equal(str, "sphere_dots")) {
+    return BOUNDARY_SPHERE_DOTS;
+  } else if (is_equal(str, "sphere_wireframe")) {
+    return BOUNDARY_SPHERE_WIREFRAME;
+  } else {
+    return BOUNDARY_NONE;
+  }
+}
+
+
+static const char *
+Params3d_boundary2str(const Boundaries_t b)
+{
+  assert((b >= BOUNDARY_NONE) && (b < NB_BOUNDARIES));
+  switch (b) {
+    case BOUNDARY_NONE:
+      return "none";
+
+    case BOUNDARY_CUBE:
+      return "cube";
+
+    case BOUNDARY_SPHERE_DOTS:
+      return "sphere_dots";
+
+    case BOUNDARY_SPHERE_WIREFRAME:
+      return "sphere_wireframe";
+
+    default:
+      return NULL;
+  }
+}
+
+
+void
+Params3d_from_json(Params3d_t *p, const json_t *json)
+{
+  if (NULL != json) {
+    // we suppose that json comes from Params3d_to_json
+    json_t *array;
+
+    zero_3d(p);
+    p->rotate_amount = json_real_value(json_object_get(json, "rotate_amount"));
+    array = json_object_get(json, "rotate_factor");
+    for (uint8_t i = X_AXIS; i <= Z_AXIS; i++) {
+      p->rotate_factor[i] = json_integer_value(json_array_get(array, i));
+    }
+    array = json_object_get(json, "rotations");
+    for (uint8_t i = X_AXIS; i <= Z_AXIS; i++) {
+      p->rotations[i] = json_real_value(json_array_get(array, i));
+    }
+    p->scale_factor_coeff = json_integer_value(json_object_get(json, "scale_factor_coeff"));
+    p->boundary = Params3d_str2boundary(json_string_value(json_object_get(json, "boundary")));
+    Params3d_set_scale_factor(p);
+  } else {
+    Params3d_set_defaults(p);
+  }
+}
+
+
+json_t *
+Params3d_to_json(const Params3d_t *p)
+{
+  json_t *res = json_object();
+  json_t *rotate_factor = json_array();
+  json_t *rotations = json_array();
+
+  json_object_set_new(res, "rotate_amount", json_real(p->rotate_amount));
+  for (uint8_t i = X_AXIS; i <= Z_AXIS; i++) {
+    json_array_append_new(rotate_factor, json_integer(p->rotate_factor[i]));
+  }
+  json_object_set_new(res, "rotate_factor", rotate_factor);
+  for (uint8_t i = X_AXIS; i <= Z_AXIS; i++) {
+    json_array_append_new(rotations, json_real(p->rotations[i]));
+  }
+  json_object_set_new(res, "rotations", rotations);
+  json_object_set_new(res, "scale_factor_coeff", json_integer(p->scale_factor_coeff));
+  json_object_set_new(res, "boundary", json_string(Params3d_boundary2str(p->boundary)));
+
+  return res;
+}
+
+
+void
+Params3d_zoom_in(Params3d_t *p)
+{
+  p->scale_factor_coeff--;
+  Params3d_set_scale_factor(p);
+}
+
+
+void
+Params3d_zoom_out(Params3d_t *p)
+{
+  p->scale_factor_coeff++;
+  Params3d_set_scale_factor(p);
+}
+
+
+void
+Params3d_set_rotate_factor(Params3d_t *p, const enum Axes axis, const int8_t value)
+{
+  p->rotate_factor[axis] = value;
+}
