@@ -99,7 +99,7 @@ Particle_new_rgba(float ttl, rgba_t rgba, Point3d_t pos, Point3d_t vel, Point3d_
 }
 
 
-u_char
+uint8_t
 Particle_System_can_add(const Particle_System_t *ps)
 {
   if (ps->max_particles == PS_NOLIMIT) {
