@@ -50,8 +50,8 @@ Particle_t *Particle_new_rgba(float, rgba_t, Point3d_t, Point3d_t, Point3d_t, fl
 /* -------------------------------------------------------- */
 
 typedef struct {
-  u_long max_particles;
-  u_long nb_particles;
+  uint32_t max_particles;
+  uint32_t nb_particles;
   GSList *particles;
 } Particle_System_t;
 
@@ -59,14 +59,14 @@ typedef struct {
 Particle_System_t *Particle_System_new(const long);
 void Particle_System_delete(Particle_System_t *);
 
-u_char Particle_System_can_add(const Particle_System_t *);
+uint8_t Particle_System_can_add(const Particle_System_t *);
 void   Particle_System_add(Particle_System_t *, const Particle_t *);
 void   Particle_System_go(Particle_System_t *);
 void   Particle_System_draw(const Particle_System_t *, const Params3d_t *, Buffer8_t *);
 
-static inline u_short Particle_System_is_dead(const Particle_System_t *ps)
+static inline uint16_t Particle_System_is_dead(const Particle_System_t *ps)
 {
-  return (u_short)(ps->nb_particles == 0);
+  return (uint16_t)(ps->nb_particles == 0);
 }
 
 #endif /* __BINIOU_PARTICLES_H */
