@@ -22,9 +22,11 @@
 #include "paths.h"
 
 Paths_t *paths = NULL;
+char **paths_list;
+
 
 static inline int
-in_range(char *name, u_short line, float vmin, float vmax, float value)
+in_range(char *name, uint16_t line, float vmin, float vmax, float value)
 {
   if ((value < vmin) || (value > vmax)) {
     xerror("[p] Line %u, %s must be in [%f %f], found %s = %f\n", line, name, vmin, vmax, name, value);
@@ -73,7 +75,7 @@ Path_load(Path_t *path, const char *filename)
   fseek(stream, 0, SEEK_SET);
   path->data = xcalloc(1, sizeof(Path_point_t) * path->size);
   ret = 1;
-  for (u_long i = 0; ret > 0 && ret != EOF; i++) {
+  for (uint32_t i = 0; ret > 0 && ret != EOF; i++) {
     ret = fscanf(stream, "%f,%f,%f,%f,%f,%f",
                  &(path->data[i].x), &(path->data[i].y), &(path->data[i].z),
                  &(path->data[i].connect), &(path->data[i].radius), &(path->data[i].c));
@@ -124,8 +126,8 @@ Paths_new(const char *directoryname)
 
   dir = opendir(directoryname);
   if (NULL == dir) {
-    VERBOSE(fprintf(stdout, "[!] Error while reading paths directory content: %s\n",
-                    strerror(errno)));
+    VERBOSE(printf("[-] Error while reading paths directory content: %s\n", strerror(errno)));
+
     return;
   }
 
@@ -204,7 +206,6 @@ Paths_new(const char *directoryname)
   }
 
   if (libbiniou_verbose) {
-    printf("done.\n");
     printf("[c] Loaded %d paths\n", size);
   }
 }
