@@ -108,7 +108,7 @@ Plugin_load(Plugin_t *p)
   p->jthread = (void *(*)(void *)) dlsym(p->handle, "jthread");
   B_GOTSYM(p->jthread, "jthread");
 
-  p->parameters = (json_t *(*)(struct Context_s *, const json_t *)) dlsym(p->handle, "parameters");
+  p->parameters = (json_t *(*)(struct Context_s *, const json_t *, const uint8_t)) dlsym(p->handle, "parameters");
   B_GOTSYM(p->parameters, "parameters");
   p->command = (json_t *(*)(struct Context_s *, const json_t *)) dlsym(p->handle, "command");
   B_GOTSYM(p->command, "command");
@@ -125,7 +125,7 @@ Plugin_unload(Plugin_t *p)
   /* FIXME error checking there, ie if plugin fails to destroy */
   if (NULL != p->jthread) {
     VERBOSE(printf("[p] Joining thread from plugin '%s'... ", p->name));
-    pthread_join(p->thread, NULL);
+    xpthread_join(p->thread, NULL);
   } else {
     if (p->calls) {
       VERBOSE(printf("[p] Unloading plugin '%s' (%d call%s)... ", p->name, p->calls,
@@ -204,7 +204,7 @@ Plugin_init(Plugin_t *p)
   }
 
   if ((NULL != p->jthread) && res) {
-    pthread_create(&p->thread, NULL, p->jthread, (void *)context);
+    xpthread_create(&p->thread, NULL, p->jthread, (void *)context);
     VERBOSE(printf("[p] Launched thread %s\n", p->name));
   }
 
