@@ -26,7 +26,7 @@
 #define PLUGIN_PARAMETER_CHANGED 2
 
 enum PluginType { PL_INPUT, PL_MAIN, PL_OUTPUT };
-enum LayerMode { LM_NONE = 0, LM_NORMAL, LM_OVERLAY, LM_XOR, LM_AVERAGE, LM_INTERLEAVE, LM_RANDOM, NB_LAYER_MODES };
+enum LayerMode { LM_NONE = 0, LM_NORMAL, LM_OVERLAY, LM_AND, LM_OR, LM_XOR, LM_AVERAGE, LM_INTERLEAVE, LM_RANDOM, NB_LAYER_MODES };
 
 struct Context_s;
 
@@ -54,7 +54,7 @@ typedef struct Plugin_s {
   int8_t  (*check_version)(uint32_t version);	 /* returns 0 if plugin is not compatible with version */
 
   void    (*run)(struct Context_s *);	         /* run function */
-  json_t *(*parameters)(struct Context_s *, const json_t *); /* parameters managment */
+  json_t *(*parameters)(struct Context_s *, const json_t *, const uint8_t); /* parameters managment */
   void *  (*jthread)(void *);                   /* joinable thread */
 
   void    (*on_switch_on)(struct Context_s *);  /* switching on */
