@@ -30,8 +30,8 @@
 typedef struct Plugins_s {
   char      *path;
   Plugin_t **plugins;
-  short      size;
-  short      selected_idx;
+  uint16_t   size;
+  uint16_t   selected_idx;
   Plugin_t  *selected;
 } Plugins_t;
 
@@ -50,10 +50,10 @@ void Plugins_select(Plugins_t *, const Plugin_t *);
 
 void Plugins_next();
 void Plugins_prev();
-void Plugins_next_n(const u_short);
-void Plugins_prev_n(const u_short);
+void Plugins_next_n(const uint16_t);
+void Plugins_prev_n(const uint16_t);
 
-void Plugins_command(Plugins_t *, const enum Command);
+json_t *Plugins_command(Context_t *, Plugins_t *, const enum Command);
 
 void Plugins_set_blacklist(gchar **);
 
