@@ -32,7 +32,7 @@ Plugins_command_result(Context_t *ctx)
   json_object_set_new(res, "selected_plugin_dname", json_string(plugins->selected->dname));
   if (NULL != plugins->selected->parameters) {
     json_object_set_new(res, "selected_param", json_integer(plugins->selected->selected_param));
-    json_object_set_new(res, "parameters", plugins->selected->parameters(ctx, NULL));
+    json_object_set_new(res, "parameters", plugins->selected->parameters(ctx, NULL, 0));
   }
 
   return res;
