@@ -25,22 +25,25 @@
 
 
 typedef struct SchemeItem_s {
-  float              p;
-  enum PluginOptions type;
+  double             p;            // probability to add the plugin (default: 1.0)
+  uint8_t            mandatory;    // 1 if proba is 1.0
+  uint8_t            disable_lens; // do not set this plugin as lens if added
+  enum PluginOptions options;      // or-ed list of options that a plugin must have to be added
 } SchemeItem_t;
 
 
 typedef struct Schemes_s {
   SchemeItem_t **schemes;
-  u_short      size;
+  uint16_t     size;
   Shuffler_t   *shuffler;
 } Schemes_t;
 
 
 void Schemes_new(const char *);
-void Schemes_new_default();
 void Schemes_delete();
 
 void Schemes_random(Context_t *);
 
+enum PluginOptions Schemes_str2option(const char *);
+
 #endif /* __BINIOU_SCHEMES_H */
