@@ -29,7 +29,7 @@ void
 Schemes_random(Context_t *ctx)
 {
   Sequence_t *new = ctx->sm->next;
-  u_short random;
+  uint16_t random;
   char ok;
   uint16_t try = 0;
 
@@ -40,6 +40,7 @@ Schemes_random(Context_t *ctx)
 
   do {
     int i;
+    struct timeval t;
 
     ok = 1;
     if ((NULL != schemes->shuffler) && !Shuffler_ok(schemes->shuffler)) {
@@ -47,18 +48,19 @@ Schemes_random(Context_t *ctx)
       return;
     }
 
-    Sequence_clear(new, 0);
+    gettimeofday(&t, NULL);
+    Sequence_clear(new, t.tv_sec);
 
     random = (NULL != schemes->shuffler) ? Shuffler_get(schemes->shuffler) : 0;
-    for (i = 0; ok && schemes->schemes[random][i].type; i++) {
+    for (i = 0; ok && schemes->schemes[random][i].options; i++) {
       /* check if we should insert a lens or a normal plugin */
       if (drand48() <= schemes->schemes[random][i].p) {
-        const int not_lens = ((short)schemes->schemes[random][i].type < 0) ? 1 : 0;
-        const int res = Context_add_rand(new, (enum PluginOptions)(schemes->schemes[random][i].type), not_lens, ctx->locked, 1);
+        const uint8_t not_lens = schemes->schemes[random][i].disable_lens;
+        const int res = Context_add_rand(new, schemes->schemes[random][i].options, not_lens, ctx->locked, 1);
 
         /* if ((res == -1) && (schemes->schemes[random][i].p == 1.0)) { */
         /* this is the correct way to check with floats: */
-        if ((res == -1) && (fabs(schemes->schemes[random][i].p - 1.0) <= FLT_EPSILON)) {
+        if ((res == -1) && schemes->schemes[random][i].mandatory) {
           /* could not find a mandatory plugin */
 #ifdef DEBUG
           printf("[!] Marking scheme %d as invalid.\n", random);
@@ -75,36 +77,39 @@ Schemes_random(Context_t *ctx)
       if (NULL != ctx->locked) {
         try++;
 #ifdef DEBUG
-        fprintf(stderr, "=== Checking for locked plugin '%s' (try: %d)... ", ctx->locked->name, try);
+        VERBOSE(printf("=== Checking for locked plugin '%s' (try: %d)... ", ctx->locked->name, try));
 #endif
         if (Sequence_find_position(new, ctx->locked) == -1) {
 #ifdef DEBUG
-          fprintf(stderr, "NOT FOUND... ");
+          VERBOSE(printf("NOT FOUND... "));
 #endif
           if (try == LOCKED_MAX_TRIES) {
 #ifdef DEBUG
-              fprintf(stderr, "max tries (%d) reached, giving up !\r\n", LOCKED_MAX_TRIES);
+              VERBOSE(printf("max tries (%d) reached, giving up !\n", LOCKED_MAX_TRIES));
 #endif
             } else {
 #ifdef DEBUG
-            fprintf(stderr, "Retrying...\r\n");
+            VERBOSE(printf("Retrying...\n"));
 #endif
             ok = 0;
           }
         } else {
 #ifdef DEBUG
-          fprintf(stderr, "FOUND\r\n");
+          VERBOSE(printf("FOUND\n"));
 #endif
         }
-      } else {
-#ifdef DEBUG
-        fprintf(stderr, "=== No plugin locked\r\n");
-#endif
       }
     }
-
   } while (!ok);
 
+  if (NULL != new->params3d) {
+    json_decref(new->params3d);
+    new->params3d = NULL;
+  }
   Context_randomize(ctx); /* TODO rajouter auto_colormaps / auto_images dans les schemes */
   Context_set(ctx);
+
+  Sequence_t *replay = Sequence_new(0);
+  Sequence_copy(ctx, ctx->sm->cur, replay);
+  Context_add_replay(ctx, replay);
 }
