@@ -20,22 +20,29 @@
 #include "context.h"
 #include "pnglite.h"
 
+#define DIRECTORY      "/screenshots/"
+
 
 static char *
-mk_filename()
+screenshot_filename()
 {
   gchar *blah = NULL;
   const gchar *home_dir = NULL;
-  static u_long frame = 0;
+  time_t s;
+  struct tm *now;
 
+  s = time(NULL);
+  now = localtime(&s);
   home_dir = g_get_home_dir();
-  blah = g_strdup_printf("%s/." PACKAGE_NAME "/screenshots", home_dir);
+  blah = g_strdup_printf("%s/." PACKAGE_NAME DIRECTORY, home_dir);
   rmkdir(blah);
   g_free(blah);
 
-  blah = g_strdup_printf("%s/." PACKAGE_NAME "/screenshots/" PACKAGE_NAME "-%d-%06li.png",
-                         home_dir, getpid(), frame);
-  frame++;
+  blah = g_strdup_printf("%s/." PACKAGE_NAME DIRECTORY PACKAGE_NAME "-%04d-%02d-%02d_%02d-%02d-%02d.png",
+                         home_dir, now->tm_year + 1900, now->tm_mon + 1, now->tm_mday,
+                         now->tm_hour, now->tm_min, now->tm_sec);
+
+  VERBOSE(printf("[i] %s: saving screenshot to %s\n", __FILE__, blah));
 
   return blah;
 }
@@ -50,7 +57,7 @@ write_png(const char *filename, const Pixel_t *data)
   png_init((png_alloc_t)0, (png_free_t)0);
   res = png_open_file_write(&png, filename);
   if (PNG_NO_ERROR == res) {
-    res = png_set_data(&png, WIDTH, HEIGHT, 8, PNG_TRUECOLOR, (u_char *)data);
+    res = png_set_data(&png, WIDTH, HEIGHT, 8, PNG_TRUECOLOR, (uint8_t *)data);
     if (PNG_NO_ERROR != res) {
       fprintf(stderr, "[!] png_set_data: %s (%s)\n", png_error_string(res), filename);
     }
@@ -71,7 +78,7 @@ Context_screenshot(const Context_t *ctx)
   char *filename = NULL;
   Pixel_t *data = NULL;
 
-  filename = mk_filename();
+  filename = screenshot_filename();
   data = export_RGB_active_buffer(ctx, 1);
   write_png(filename, data);
 
