@@ -23,20 +23,26 @@
 #include "layer.h"
 
 
+#define UNSAVED_SEQUENCE       "(unsaved)"
+#define UNSAVED_SEQUENCE_ERROR "Sequence is not saved"
+
+
 typedef struct Sequence_s {
-  uint32_t id;              /* sequence id */
-  u_char   changed;
-  u_char   broken;          /* sequence is broken (eg, no pictures available) */
-  char     *name;
+  uint32_t  id;               // sequence id
+  uint8_t   changed;          // sequence has been modified
+  uint8_t   broken;           // sequence is broken (eg, no pictures available)
+  char      *name;            // sequence name
 
-  GList    *layers;         /* list of plugins to run */
-  Plugin_t *lens;           /* lens, NULL if none */
+  GList     *layers;          // list of plugins to run
+  Plugin_t  *lens;            // lens, NULL if none
 
-  char     auto_colormaps;  /* change colormaps at random interval (-1 == undefined) */
-  uint32_t cmap_id;         /* colormap to use, 0 if use current */
+  char       auto_colormaps;  // change colormaps at random interval (-1 == undefined)
+  uint32_t   cmap_id;         // colormap to use, 0 if use current
 
-  char     auto_images;     /* change images at random interval (-1 == undefined) */
-  uint32_t image_id;        /* image to use, 0 if use current */
+  char       auto_images;     // change images at random interval (-1 == undefined)
+  uint32_t   image_id;        // image to use, 0 if use current
+
+  json_t     *params3d;       // 3D parameters
 } Sequence_t;
 
 
@@ -49,19 +55,20 @@ void Sequence_clear(Sequence_t *, const uint32_t);
 void Sequence_changed(Sequence_t *);
 
 void Sequence_insert(Sequence_t *, Plugin_t *, const uint8_t);
-void Sequence_insert_at_position(Sequence_t *, const u_short, Plugin_t *);
+void Sequence_insert_at_position(Sequence_t *, const uint16_t, Plugin_t *);
 void Sequence_remove(Sequence_t *, const Plugin_t *);
 
 GList *Sequence_find(const Sequence_t *, const Plugin_t *);
 short Sequence_find_position(const Sequence_t *, const Plugin_t *);
 
-void Sequence_save(struct Context_s *, Sequence_t *, int, const uint8_t, const char, const char);
+void Sequence_save(struct Context_s *, int, const uint8_t, const char, const char);
 Sequence_t *Sequence_load(const char *);
+Sequence_t *Sequence_from_json(json_t *);
 
 gint Sequence_sort_func(gconstpointer, gconstpointer);
 
 uint8_t Sequence_size(const Sequence_t *);
 
-json_t *Sequence_to_json(const Sequence_t *, const uint8_t);
+json_t *Sequence_to_json(const Sequence_t *, const uint8_t, const uint8_t);
 
 #endif /* __BINIOU_SEQUENCE_H */
