@@ -48,9 +48,11 @@ void SequenceManager_default_layer_mode(const Sequence_t *);
 void SequenceManager_prev_layer_mode(const Sequence_t *);
 void SequenceManager_next_layer_mode(const Sequence_t *);
 
-void SequenceManager_command(struct Context_s *, const enum Command, const char, const char);
+json_t *SequenceManager_command(struct Context_s *, const enum Command, const char, const char);
 
 void SequenceManager_lock(SequenceManager_t *);
 void SequenceManager_unlock(SequenceManager_t *);
 
+void SequenceManager_reorder(Sequence_t *, const json_t *);
+
 #endif /* __BINIOU_SEQUENCE_MANAGER_H */
