@@ -119,7 +119,7 @@ SequenceManager_command(Context_t *ctx, const enum Command cmd, const char auto_
       printf(">>> CMD_SEQ_PARAMETER_PREVIOUS\n");
 #endif
       if (NULL != plugins->selected->parameters) {
-        json_t *j_params = plugins->selected->parameters(ctx, NULL);
+        json_t *j_params = plugins->selected->parameters(ctx, NULL, 0);
         uint8_t nb_params = plugin_parameter_number(j_params);
 
         json_decref(j_params);
@@ -136,7 +136,7 @@ SequenceManager_command(Context_t *ctx, const enum Command cmd, const char auto_
       printf(">>> CMD_SEQ_PARAMETER_NEXT\n");
 #endif
       if (NULL != plugins->selected->parameters) {
-        json_t *j_params = plugins->selected->parameters(ctx, NULL);
+        json_t *j_params = plugins->selected->parameters(ctx, NULL, 0);
         uint8_t nb_params = plugin_parameter_number(j_params);
 
         json_decref(j_params);
@@ -191,7 +191,7 @@ SequenceManager_command(Context_t *ctx, const enum Command cmd, const char auto_
       json_object_set_new(res, "selected_plugin", json_string(plugins->selected->name));
       json_object_set_new(res, "selected_plugin_dname", json_string(plugins->selected->dname));
       if (NULL != plugins->selected->parameters) {
-        json_object_set_new(res, "parameters", plugins->selected->parameters(ctx, NULL));
+        json_object_set_new(res, "parameters", plugins->selected->parameters(ctx, NULL, 0));
       }
       break;
 
@@ -204,7 +204,7 @@ SequenceManager_command(Context_t *ctx, const enum Command cmd, const char auto_
       json_object_set_new(res, "selected_plugin", json_string(plugins->selected->name));
       json_object_set_new(res, "selected_plugin_dname", json_string(plugins->selected->dname));
       if (NULL != plugins->selected->parameters) {
-        json_object_set_new(res, "parameters", plugins->selected->parameters(ctx, NULL));
+        json_object_set_new(res, "parameters", plugins->selected->parameters(ctx, NULL, 0));
       }
       break;
 
