@@ -43,7 +43,7 @@ Sequences_new()
   } else {
     // g_free(blah);
     while (NULL != (entry = readdir(dir))) {
-      if (strcmp(entry->d_name, "..")) {
+      if (!is_equal(entry->d_name, "..")) {
         Sequence_t *s = NULL;
 
         s = Sequence_load(entry->d_name);
@@ -67,7 +67,7 @@ Sequences_new()
 
 
 void
-Sequences_free()
+Sequences_delete()
 {
   GList *tmp;
 
@@ -114,6 +114,28 @@ Sequences_find(const uint32_t id)
 }
 
 
+GList *
+Sequences_find_by_name(const char *name)
+{
+  GList *tmp;
+
+  assert(NULL != sequences);
+  tmp = sequences->seqs;
+
+  while (NULL != tmp) {
+    Sequence_t *s = (Sequence_t *)tmp->data;
+
+    if (is_equal(s->name, name)) {
+      return tmp;
+    }
+
+    tmp = g_list_next(tmp);
+  }
+
+  return NULL;
+}
+
+
 void
 Sequences_set_dir(char *dir)
 {
@@ -123,8 +145,6 @@ Sequences_set_dir(char *dir)
 
 #define SAVEDIR ".lebiniou/sequences"
 
-/* FIXME check for possible memory leak (sequences_dir),
-   should be freed by Sequences_delete() */
 const char *
 Sequences_get_dir()
 {
