@@ -26,15 +26,16 @@
 
 typedef struct Sequences_s {
   GList      *seqs;
-  u_short    size;
+  uint16_t    size;
   Shuffler_t *shuffler;
 } Sequences_t;
 
 
 void Sequences_new();
-void Sequences_free();
+void Sequences_delete();
 
 GList *Sequences_find(const uint32_t);
+GList *Sequences_find_by_name(const char *);
 
 void Sequences_set_dir(char *);
 const char *Sequences_get_dir();
