@@ -26,9 +26,7 @@ sighandle(int sig)
 {
   printf("\n[+] Got signal %d !\n", sig);
   biniou_stop();
-#ifdef WITH_ULFIUS
   Context_stop_ulfius(context);
-#endif
   biniou_delete();
   remove_pid_file();
   exit(0);
