@@ -26,7 +26,7 @@
 static void
 Translation_build(Translation_t *t)
 {
-  u_short i, j;
+  uint16_t i, j;
   M_wPoint_t *wp = t->point;
 
   for (j = 0; j < HEIGHT; j++)
@@ -73,13 +73,13 @@ Translation_idle(const Translation_t *t, const Context_t *ctx)
   const Buffer8_t *src = active_buffer(ctx);
   Buffer8_t *dst = passive_buffer(ctx);
   M_wPoint_t *p = t->point;
-  u_short i, j;
+  uint16_t i, j;
 
   for (j = 0; j < HEIGHT; j++)
     for (i = 0; i < WIDTH; i++) {
       set_pixel_nc(dst, i, j,
-                   get_pixel_nc(src, (u_short)p[j * WIDTH + i].x,
-                                (u_short)p[j * WIDTH + i].y));
+                   get_pixel_nc(src, (uint16_t)p[j * WIDTH + i].x,
+                                (uint16_t)p[j * WIDTH + i].y));
     }
 }
 
@@ -90,7 +90,7 @@ Translation_fade(Translation_t *t, const Context_t *ctx)
   const Buffer8_t *src = active_buffer(ctx);
   Buffer8_t *dst = passive_buffer(ctx);
   M_wPoint_t *p = t->point;
-  u_short i, j;
+  uint16_t i, j;
 
   for (j = 0; j < HEIGHT; j++)
     for (i = 0; i < WIDTH; i++) {
@@ -98,16 +98,16 @@ Translation_fade(Translation_t *t, const Context_t *ctx)
       p[j * WIDTH + i].y += p[j * WIDTH + i].dy;
 
       set_pixel_nc(dst, i, j, get_pixel_nc(src,
-                                           (u_short)(p[j * WIDTH + i].x + WIDTH ) % WIDTH,
-                                           (u_short)(p[j * WIDTH + i].y + HEIGHT) % HEIGHT));
+                                           (uint16_t)(p[j * WIDTH + i].x + WIDTH ) % WIDTH,
+                                           (uint16_t)(p[j * WIDTH + i].y + HEIGHT) % HEIGHT));
     }
 
   /* save coordinages cropped to screen size */
   if (--t->fading == 0)
     for (j = 0; j < HEIGHT; j++)
       for (i = 0; i < WIDTH; i++) {
-        p[j * WIDTH + i].x = (u_short)(p[j * WIDTH + i].x + WIDTH) % WIDTH;
-        p[j * WIDTH + i].y = (u_short)(p[j * WIDTH + i].y + HEIGHT) % HEIGHT;
+        p[j * WIDTH + i].x = (uint16_t)(p[j * WIDTH + i].x + WIDTH) % WIDTH;
+        p[j * WIDTH + i].y = (uint16_t)(p[j * WIDTH + i].y + HEIGHT) % HEIGHT;
       }
 }
 
@@ -115,7 +115,7 @@ Translation_fade(Translation_t *t, const Context_t *ctx)
 void
 Translation_compute(Translation_t *t)
 {
-  u_short k;
+  uint16_t k;
 
   assert(NULL != t);
   for (k = 0; (k < BATCH_LINES) && !Translation_batch_done(t); k++)
@@ -161,12 +161,12 @@ Translation_batch_init(Translation_t *t)
 }
 
 
-u_char
+uint8_t
 Translation_batch_line(Translation_t *t)
 {
   M_wPoint_t *wp = &t->point[t->line * WIDTH];
 
-  for (u_short i = 0; i < WIDTH; i++) {
+  for (uint16_t i = 0; i < WIDTH; i++) {
     Map_t m = t->f(wp->x, wp->y);
     wp->dx  = (float)((float)m.map_x - (float)wp->x) / FADE_STEPS;
     wp->dy  = (float)((float)m.map_y - (float)wp->y) / FADE_STEPS;
@@ -182,7 +182,7 @@ Translation_batch_line(Translation_t *t)
 }
 
 
-u_char
+uint8_t
 Translation_batch_done(const Translation_t *t)
 {
   return (t->line == HEIGHT);
