@@ -313,3 +313,58 @@ safe_filename(const char *filename)
 
   return 1;
 }
+
+
+void
+xpthread_create(pthread_t *thread, const pthread_attr_t *attr,
+                     void *(*start_routine) (void *), void *arg)
+{
+  if (pthread_create(thread, attr, start_routine, arg) != 0) {
+    xerror("pthread_create failed\n");
+  }
+}
+
+
+void
+xpthread_join(pthread_t thread, void **retval)
+{
+  if (pthread_join(thread, retval) != 0) {
+    xerror("pthread_join failed\n");
+  }
+}
+
+
+void
+xpthread_mutex_lock(pthread_mutex_t *mutex)
+{
+  if (pthread_mutex_lock(mutex) != 0) {
+    xerror("xpthread_mutex_lock failed\n");
+  }
+}
+
+
+void
+xpthread_mutex_unlock(pthread_mutex_t *mutex)
+{
+  if (pthread_mutex_unlock(mutex) != 0) {
+    xerror("xpthread_mutex_lock failed\n");
+  }
+}
+
+
+void
+xpthread_mutex_destroy(pthread_mutex_t *mutex)
+{
+  if (pthread_mutex_destroy(mutex) != 0) {
+    xerror("xpthread_mutex_destroy failed\n");
+  }
+}
+
+
+void
+xpthread_mutex_init(pthread_mutex_t *restrict mutex, const pthread_mutexattr_t *restrict attr)
+{
+  if (pthread_mutex_init(mutex, attr) != 0) {
+    xerror("xpthread_mutex_init failed\n");
+  }
+}
