@@ -75,4 +75,13 @@ int is_equal(const char *, const char *);
 
 int safe_filename(const char *);
 
+// threads
+void xpthread_create(pthread_t *thread, const pthread_attr_t *attr,
+                     void *(*start_routine) (void *), void *arg);
+void xpthread_join(pthread_t thread, void **retval);
+void xpthread_mutex_lock(pthread_mutex_t *mutex);
+void xpthread_mutex_unlock(pthread_mutex_t *mutex);
+void xpthread_mutex_destroy(pthread_mutex_t *mutex);
+void xpthread_mutex_init(pthread_mutex_t *restrict mutex, const pthread_mutexattr_t *restrict attr);
+
 #endif /* __BINIOU_UTILS_H */
