@@ -57,8 +57,8 @@ typedef struct {
   int       fd;
   int       n_buffers;
   buffer_t  *buffers;
-  int       hflip;
-  int       vflip;
+  uint8_t   hflip;
+  uint8_t   vflip;
 } webcam_t;
 
 void parse_options();
