@@ -121,10 +121,10 @@ set_ctrl(int fd, const int ctrl, const int value)
     if (errno != EINVAL) {
       xerror("VIDIOC_QUERYCTRL\n");
     } else {
-      fprintf(stderr, "V4L2_CID_BRIGHTNESS is not supported\n");
+      fprintf(stderr, "[!] V4L2_CID_BRIGHTNESS is not supported\n");
     }
   } else if (queryctrl.flags & V4L2_CTRL_FLAG_DISABLED) {
-    fprintf(stderr, "%s is not supported\n",
+    fprintf(stderr, "[!] %s is not supported\n",
             (ctrl == V4L2_CID_VFLIP) ? "V4L2_CID_VFLIP" : "V4L2_CID_HFLIP");
   } else {
     memset(&control, 0, sizeof(control));
