@@ -19,7 +19,7 @@
 
 #include "webcam.h"
 
-extern int hflip, vflip, override_webcam;
+extern uint8_t hflip, vflip, override_webcam;
 
 
 static void
@@ -45,13 +45,14 @@ process_image(webcam_t *webcam, void *p)
     }
 #endif
 
-  pthread_mutex_lock(&webcam->ctx->cam_mtx[webcam->cam_no]);
+  xpthread_mutex_lock(&webcam->ctx->cam_mtx[webcam->cam_no]);
   dst = webcam->ctx->cam_save[webcam->cam_no][0];
 
   if ((WIDTH == CAP_WIDTH) && (HEIGHT == CAP_HEIGHT)) {
     memcpy(dst->buffer, temp, BUFFSIZE*sizeof(Pixel_t));
   } else {
     gray_scale(dst->buffer, CAP_WIDTH, CAP_HEIGHT, temp);
+    Buffer8_YUV_to_full_gray(dst);
   }
 
   if (hflip) {
@@ -64,7 +65,7 @@ process_image(webcam_t *webcam, void *p)
 
   save = Buffer8_clone(dst); /* TODO s/save/new_picture */
   Context_push_webcam(webcam->ctx, save, webcam->cam_no);
-  pthread_mutex_unlock(&webcam->ctx->cam_mtx[webcam->cam_no]);
+  xpthread_mutex_unlock(&webcam->ctx->cam_mtx[webcam->cam_no]);
 }
 
 
