@@ -20,7 +20,7 @@
 #include "webcam.h"
 
 
-extern u_long options;
+extern uint32_t options;
 extern char *video_base;
 
 int
