@@ -19,7 +19,7 @@
 
 #include "webcam.h"
 
-extern int hflip, vflip, webcams;
+extern uint8_t hflip, vflip, desired_webcams;
 extern char *video_base;
 
 
@@ -36,8 +36,8 @@ process_token(const char *tok)
   if (is_equal((const char *)*vv, "webcams")) {
     vv++;
     assert(NULL != *vv);
-    webcams = xatol(*vv);
-    VERBOSE(printf("[E] webcam: grabbing %d device%s\n", webcams, (webcams == 1) ? "" : "s"));
+    desired_webcams = xatol(*vv);
+    VERBOSE(printf("[E] webcam: grabbing %d device%s\n", desired_webcams, (desired_webcams == 1) ? "" : "s"));
   }
   if (is_equal((const char *)*vv, "device")) {
     vv++;
